@@ -1,4 +1,4 @@
-#![cfg_attr(not(feature = "std"), no_std)]
+#![cfg_attr(not(test), no_std)]
 #![doc = include_str!("../README.md")]
 
 #[cfg(test)]
